
(_changelog)=
# Changelog

## Unreleased

## 2024.01.0
- Add support for Python 3.12 wheels
- Remove support for Python versions below 3.10
- SASKTRAN2 is now available in conda-forge
- Added the {py:class}`sasktran2.LinearizedMie` object to perform Mie calculations
- Added support for `sk.GeometryType.PlaneParallel` and `sk.GeometryType.PseudoSpherical`

## 2023.12.0
- First official release
